import React, { useState } from 'react'
import { useDrop } from 'react-dnd'
import { Button } from 'antd'
import { is, fromJS } from 'immutable'
import update from 'immutability-helper'
import Card from './card'
import ItemTypes from './itemtypes'
import './index.scss'

const Container = ({change, list, handlePreviewList, handleMenu, deleteMemu, handleButton }) => {
  const [cards, setCards] = useState(list)
  const moveCard = (id, atIndex) => {
    const { card, index } = findCard(id)
    const _cards = update(cards, { $splice: [[index, 1], [atIndex, 0, card]] })
    setCards(_cards)
    handlePreviewList(_cards)
  }

  if (!is(fromJS(cards), fromJS(list))) {
    setCards(list)
  }

  const findCard = id => {
    const card = cards.filter(c => c.MenuID === id)[0]
    return {
      card,
      index: cards.indexOf(card),
    }
  }

  const editCard = id => {
    const { card, index } = findCard(id)
    handleMenu({
      card,
      index,
      type: 'edit'
    })
  }

  const delCard = id => {
    const { card } = findCard(id)
    deleteMemu(card)
  }

  const confirm = () => {
    handleButton('confirm')
  }

  const cancel = () => {
    handleButton('cancel')
  }

  const [, drop] = useDrop({ accept: ItemTypes.CARD })
  return (
    <div ref={drop} className="dragdashboard">
      {cards.map(card => (
        <Card
          key={card.MenuID}
          id={`${card.MenuID}`}
          text={card.MenuName}
          moveCard={moveCard}
          editCard={editCard}
          delCard={delCard}
          findCard={findCard}
        />
      ))}
      <Button type="primary" className="mk-save-menu" disabled={!change} onClick={confirm}>保存</Button>
      <Button onClick={cancel}>关闭</Button>
    </div>
  )
}
export default Container
